@@ -59,13 +59,13 @@ class TabularFormatter(FormatterBase):
             #                 record[f"properties.{prop}"] = str(val)
             #         records.append(record)
             df = pd.DataFrame.from_records(records)
+            filename = f"file.{parameters.format.value}"
+            if document.properties and "fileName" in document.properties:
+                filepath = Path(document.properties['fileName'])
+                filename = f"{filepath.stem}.{parameters.format.value}"
             if parameters.format == OutputFormat.xlsx:
                 bio = io.BytesIO()
                 df.to_excel(bio)
-                filename = f"file.{OutputFormat.xlsx.value}"
-                if document.properties and "fileName" in document.properties:
-                    filepath = Path(document.properties['fileName'])
-                    filename = f"{filepath.stem}.{OutputFormat.xlsx.value}"
                 resp = Response(content=bio.getvalue(),
                                 media_type="application/vnd.openxmlformats-officedocument.spreadsheetml.sheet")
                 resp.headers["Content-Disposition"] = f"attachment; filename={filename}"
@@ -74,6 +74,7 @@ class TabularFormatter(FormatterBase):
                 df.to_csv(sio, index=False)
                 resp = Response(content=sio.getvalue(),
                                 media_type="text/csv")
+                resp.headers["Content-Disposition"] = f"attachment; filename={filename}"
             return resp
         except BaseException as err:
             raise err
